@@ -32,6 +32,10 @@ class Config(object):
     # Scale order range
     x_scale = 1
     y_scale = 1
+    # Display values in human readable format (ie: 12.4M)
+    human_readable = False
+    # Display values in logarithmic scale
+    logarithmic = False
     # If set to a filename, this will replace the default css
     base_css = None
     # or default js
@@ -40,7 +44,8 @@ class Config(object):
     style = DefaultStyle
     # Various font sizes
     label_font_size = 10
-    values_font_size = 18
+    value_font_size = 8
+    tooltip_font_size = 20
     title_font_size = 16
     legend_font_size = 14
     # Specify labels rotation angles in degrees
@@ -75,7 +80,14 @@ class Config(object):
     interpolate = None
     # Number of interpolated points between two values
     interpolation_precision = 250
+    # Set the ordinate zero value (for filling)
     zero = 0
+    # Text to display when no data is given
+    no_data_text = "No data"
+    # Print values when graph is in non interactive mode
+    print_values = True
+    # Print zeroes when graph is in non interactive mode
+    print_zeroes = False
 
     def __init__(self, **kwargs):
         """Can be instanciated with config kwargs"""
@@ -85,12 +97,13 @@ class Config(object):
         """Can be updated with kwargs"""
         self.__dict__.update(kwargs)
 
-    @property
-    def font_sizes(self):
+    def font_sizes(self, with_unit=True):
         fs = FontSizes()
         for name in dir(self):
             if name.endswith('_font_size'):
-                setattr(fs,
-                        name.replace('_font_size', ''),
-                        '%dpx' % getattr(self, name))
+                setattr(
+                    fs,
+                    name.replace('_font_size', ''),
+                    ('%dpx' % getattr(self, name)
+                    ) if with_unit else getattr(self, name))
         return fs
