@@ -1,5 +1,6 @@
 from pygal.graph.base import BaseGraph
-from pygal.view import View
+from pygal.view import View, LogView
+from pygal.util import is_major
 
 
 class Graph(BaseGraph):
@@ -14,7 +15,7 @@ class Graph(BaseGraph):
         self._title()
 
     def _set_view(self):
-        self.view = View(
+        self.view = (LogView if self.logarithmic else View)(
             self.width - self.margin.x,
             self.height - self.margin.y,
             self._box)
@@ -40,6 +41,35 @@ class Graph(BaseGraph):
             self.graph_node, class_="plot overlay",
             transform="translate(%d, %d)" % (
                 self.margin.left, self.margin.top))
+        self.text_overlay = self.svg.node(
+            self.graph_node, class_="plot text-overlay",
+            transform="translate(%d, %d)" % (
+                self.margin.left, self.margin.top))
+        tooltip_overlay = self.svg.node(
+            self.graph_node, class_="plot tooltip-overlay",
+            transform="translate(%d, %d)" % (
+                self.margin.left, self.margin.top))
+        self.tooltip_node = self.svg.node(tooltip_overlay, id="tooltip",
+                                          transform='translate(0 0)')
+        # self.svg.node(
+        #     self.tooltip_node, 'animateTransform',
+        #     id="tooltip-slide",
+        #     attributeName='transform',
+        #     attributeType='XML',
+        #     type='translate',
+        #     calcMode='spline',
+        #     dur='100ms',
+        #     end='indefinite',
+        #     begin='indefinite',
+        #     from_="0 0",
+        #     to="100 100",
+        #     fill='freeze')
+
+        self.svg.node(self.tooltip_node, 'rect',
+                      id="tooltip-box",
+                      rx=5, ry=5,
+        )
+        self.svg.node(self.tooltip_node, 'text')
 
     def _x_axis(self):
         if not self._x_labels:
@@ -79,16 +109,21 @@ class Graph(BaseGraph):
                       d='M%f %f h%f' % (0, self.view.height, self.view.width),
                       class_='line')
         for label, position in self._y_labels:
-            guides = self.svg.node(axis, class_='guides')
+            major = is_major(position)
+            guides = self.svg.node(axis, class_='%sguides' % (
+                'logarithmic ' if self.logarithmic else ''
+            ))
             x = -5
             y = self.view.y(position)
             self.svg.node(guides, 'path',
-                      d='M%f %f h%f' % (0, y, self.view.width),
-                      class_='%sline' % (
-                          'guide ' if position != 0 else ''))
+                          d='M%f %f h%f' % (0, y, self.view.width),
+                          class_='%s%sline' % (
+                              'major ' if major else '',
+                              'guide ' if position != 0 else ''))
             text = self.svg.node(guides, 'text',
-                             x=x,
-                             y=y + .35 * self.label_font_size
+                                 x=x,
+                                 y=y + .35 * self.label_font_size,
+                                 class_='major' if major else ''
             )
             text.text = label
             if self.y_label_rotation:
@@ -134,7 +169,11 @@ class Graph(BaseGraph):
     def _serie(self, serie):
         return dict(
             plot=self.svg.node(
-                self.plot, class_='series serie-%d color-%d' % (serie, serie)),
+                self.plot,
+                class_='series serie-%d color-%d' % (serie, serie)),
             overlay=self.svg.node(
-                self.overlay, class_='series serie-%d color-%d' % (
-                    serie, serie)))
+                self.overlay,
+                class_='series serie-%d color-%d' % (serie, serie)),
+            text_overlay=self.svg.node(
+                self.text_overlay,
+                class_='series serie-%d color-%d' % (serie, serie)))
